@@ -1,81 +1,72 @@
 <?php
-# Mantis - a php based bugtracking system
+# MantisBT - a php based bugtracking system
 
-# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
-# Copyright (C) 2002 - 2007  Mantis Team   - mantisbt-dev@lists.sourceforge.net
-
-# Mantis is free software: you can redistribute it and/or modify
+# MantisBT is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 2 of the License, or
 # (at your option) any later version.
 #
-# Mantis is distributed in the hope that it will be useful,
+# MantisBT is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with Mantis.  If not, see <http://www.gnu.org/licenses/>.
+# along with MantisBT.  If not, see <http://www.gnu.org/licenses/>.
 
-	# --------------------------------------------------------
-	# $Id: account_prof_menu_page.php,v 1.39.2.1 2007-10-13 22:32:18 giallu Exp $
-	# --------------------------------------------------------
-?>
-<?php
-	# This page allows users to add a new profile which is POSTed to
-	# account_prof_add.php
+	/**
+	 * This page allows users to add a new profile which is POSTed to
+	 * account_prof_add.php
+	 *
+	 * Users can also manage their profiles
+	 *
+	 * @package MantisBT
+	 * @copyright Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
+	 * @copyright Copyright (C) 2002 - 2012  MantisBT Team - mantisbt-dev@lists.sourceforge.net
+	 * @link http://www.mantisbt.org
+	 */
+	 /**
+	  * MantisBT Core API's
+	  */
+	require_once( 'core.php' );
 
-	# Users can also manage their profiles
-?>
-<?php
 	if ( isset( $g_global_profiles ) ) {
 		$g_global_profiles = true;
 	} else {
 		$g_global_profiles = false;
 	}
-?>
-<?php
-	require_once( 'core.php' );
 
-	$t_core_path = config_get( 'core_path' );
+	require_once( 'current_user_api.php' );
 
-	require_once( $t_core_path.'current_user_api.php' );
-?>
-<?php
 	auth_ensure_user_authenticated();
 
 	current_user_ensure_unprotected();
-?>
-<?php
+
 	if ( $g_global_profiles ) {
 		access_ensure_global_level( config_get( 'manage_global_profile_threshold' ) );
 	} else {
 		access_ensure_global_level( config_get( 'add_profile_threshold' ) );
 	}
-?>
-<?php html_page_top1( lang_get( 'manage_profiles_link' ) ) ?>
-<?php html_page_top2() ?>
 
-<?php
+	html_page_top( lang_get( 'manage_profiles_link' ) );
+
 	if ( $g_global_profiles ) {
 		print_manage_menu( 'manage_prof_menu_page.php' );
 	}
-?>
 
-<?php
 	if ( $g_global_profiles ) {
 		$t_user_id = ALL_USERS;
 	} else {
 		$t_user_id = auth_get_current_user_id();
 	}
-?>
 
-<?php # Add Profile Form BEGIN ?>
+	# Add Profile Form BEGIN
+?>
 <br />
 <div align="center">
 <form method="post" action="account_prof_update.php">
 <?php  echo form_security_field( 'profile_update' )?>
-<input type="hidden" name="action" value="add">
+<input type="hidden" name="action" value="add" />
 <table class="width75" cellspacing="1">
 <tr>
 	<td class="form-title">
@@ -108,7 +99,7 @@
 </tr>
 <tr class="row-1">
 	<td class="category">
-		<span class="required">*</span><?php echo lang_get( 'version' ) ?>
+		<span class="required">*</span><?php echo lang_get( 'os_version' ) ?>
 	</td>
 	<td>
 		<input type="text" name="os_build" size="16" maxlength="16" />
@@ -133,12 +124,12 @@
 </table>
 </form>
 </div>
-<?php # Add Profile Form END ?>
-
-<?php # Edit or Delete Profile Form BEGIN ?>
 <?php 
+	# Add Profile Form END
+	# Edit or Delete Profile Form BEGIN
+
 	$t_profiles = profile_get_all_for_user( $t_user_id );
-	if( $t_profiles ) { 
+	if( $t_profiles ) {
 ?>
 <br />
 <div align="center">
@@ -181,7 +172,7 @@
 </table>
 </form>
 </div>
-<?php } ?>
-<?php # Edit or Delete Profile Form END ?>
+<?php 
+} # Edit or Delete Profile Form END
 
-<?php html_page_bottom1( __FILE__ ) ?>
+html_page_bottom();
