@@ -1,38 +1,37 @@
 <?php
-# Mantis - a php based bugtracking system
+# MantisBT - a php based bugtracking system
 
-# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
-# Copyright (C) 2002 - 2007  Mantis Team   - mantisbt-dev@lists.sourceforge.net
-
-# Mantis is free software: you can redistribute it and/or modify
+# MantisBT is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 2 of the License, or
 # (at your option) any later version.
 #
-# Mantis is distributed in the hope that it will be useful,
+# MantisBT is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with Mantis.  If not, see <http://www.gnu.org/licenses/>.
-
-	# --------------------------------------------------------
-	# $Id: manage_custom_field_page.php,v 1.19.2.1 2007-10-13 22:33:28 giallu Exp $
-	# --------------------------------------------------------
+# along with MantisBT.  If not, see <http://www.gnu.org/licenses/>.
 
+	/**
+	 * @package MantisBT
+	 * @copyright Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
+	 * @copyright Copyright (C) 2002 - 2012  MantisBT Team - mantisbt-dev@lists.sourceforge.net
+	 * @link http://www.mantisbt.org
+	 */
+	 /**
+	  * MantisBT Core API's
+	  */
 	require_once( 'core.php' );
 
-	$t_core_path = config_get( 'core_path' );
-
-	require_once( $t_core_path.'custom_field_api.php' );
+	require_once( 'custom_field_api.php' );
 
 	auth_reauthenticate();
 
 	access_ensure_global_level( config_get( 'manage_custom_fields_threshold' ) );
 
-	html_page_top1( lang_get( 'manage_custom_field_link' ) );
-	html_page_top2();
+	html_page_top( lang_get( 'manage_custom_field_link' ) );
 
 	print_manage_menu( 'manage_custom_field_page.php' );
 ?>
@@ -61,9 +60,6 @@
 		<td class="category" width="12%">
 			<?php echo lang_get( 'custom_field_default_value' ) ?>
 		</td>
-		<td class="category" width="12%">
-			<?php echo lang_get( 'custom_field_advanced' ) ?>
-		</td>
 	</tr>
 	<?php
 		$t_custom_fields = custom_field_get_ids();
@@ -87,9 +83,6 @@
 			<td>
 				<?php echo string_display( $t_desc['default_value'] ) ?>
 			</td>
-			<td align="center">
-				<?php echo trans_bool( $t_desc['advanced'] ) ?>
-			</td>
 		</tr>
 	<?php
 		} # Create Form END
@@ -106,4 +99,5 @@
 
 <br />
 
-<?php html_page_bottom1( __FILE__ ) ?>
+<?php
+	html_page_bottom();
