@@ -1,39 +1,59 @@
 <?php
-# Mantis - a php based bugtracking system
+# MantisBT - a php based bugtracking system
 
-# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
-# Copyright (C) 2002 - 2007  Mantis Team   - mantisbt-dev@lists.sourceforge.net
-
-# Mantis is free software: you can redistribute it and/or modify
+# MantisBT is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 2 of the License, or
 # (at your option) any later version.
 #
-# Mantis is distributed in the hope that it will be useful,
+# MantisBT is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with Mantis.  If not, see <http://www.gnu.org/licenses/>.
-
-	# --------------------------------------------------------
-	# $Id: manage_user_edit_page.php,v 1.18.2.1 2007-10-13 22:33:54 giallu Exp $
-	# --------------------------------------------------------
+# along with MantisBT.  If not, see <http://www.gnu.org/licenses/>.
 
+	/**
+	 * @package MantisBT
+	 * @copyright Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
+	 * @copyright Copyright (C) 2002 - 2012  MantisBT Team - mantisbt-dev@lists.sourceforge.net
+	 * @link http://www.mantisbt.org
+	 */
+	 /**
+	  * MantisBT Core API's
+	  */
 	require_once( 'core.php' );
 
 	auth_reauthenticate();
 
 	access_ensure_global_level( config_get( 'manage_user_threshold' ) );
 
-	$f_user_id = gpc_get_int( 'user_id' );
-	$c_user_id = $f_user_id;
+	$f_username = gpc_get_string( 'username', '' );
 
-	$t_user = user_get_row( $f_user_id );
+	if ( is_blank( $f_username ) ) {
+		$t_user_id = gpc_get_int( 'user_id' );
+	} else {
+		$t_user_id = user_get_id_by_name( $f_username );
+		if ( $t_user_id === false ) {
+			# If we can't find the user by name, attempt to find by email.
+			$t_user_id = user_get_id_by_email( $f_username );
+			if ( $t_user_id === false ) {
+				error_parameters( $f_username );
+				trigger_error( ERROR_USER_BY_NAME_NOT_FOUND, ERROR );
+			}
+		}
+	}
 
-	html_page_top1();
-	html_page_top2();
+	$t_user = user_get_row( $t_user_id );
+
+	# Ensure that the account to be updated is of equal or lower access to the
+	# current user.
+	access_ensure_global_level( $t_user['access_level'] );
+
+	$t_ldap = ( LDAP == config_get( 'login_method' ) );
+
+	html_page_top();
 
 	print_manage_menu();
 ?>
@@ -57,41 +77,67 @@
 <!-- Username -->
 <tr <?php echo helper_alternate_class( 1 ) ?>>
 	<td class="category" width="30%">
-		<?php echo lang_get( 'username' ) ?>:
+		<?php echo lang_get( 'username' ) ?>
 	</td>
 	<td width="70%">
-		<input type="text" size="16" maxlength="32" name="username" value="<?php echo $t_user['username'] ?>" />
+		<input type="text" size="32" maxlength="<?php echo DB_FIELD_SIZE_USERNAME;?>" name="username" value="<?php echo string_attribute( $t_user['username'] ) ?>" />
 	</td>
 </tr>
 
 <!-- Realname -->
 <tr <?php echo helper_alternate_class( 1 ) ?>>
 	<td class="category" width="30%">
-		<?php echo lang_get( 'realname' ) ?>:
+		<?php echo lang_get( 'realname' ) ?>
 	</td>
 	<td width="70%">
-		<input type="text" size="16" maxlength="100" name="realname" value="<?php echo string_attribute( $t_user['realname'] ) ?>" />
+		<?php
+			// With LDAP
+			if ( $t_ldap && ON == config_get( 'use_ldap_realname' ) ) {
+				echo string_display_line( user_get_realname( $t_user_id ) );
+			}
+			// Without LDAP
+			else {
+		?>
+			<input type="text" size="32" maxlength="<?php echo DB_FIELD_SIZE_REALNAME;?>" name="realname" value="<?php echo string_attribute( $t_user['realname'] ) ?>" />
+		<?php
+			}
+		?>
 	</td>
 </tr>
 
 <!-- Email -->
 <tr <?php echo helper_alternate_class() ?>>
 	<td class="category">
-		<?php echo lang_get( 'email' ) ?>:
+		<?php echo lang_get( 'email' ) ?>
 	</td>
 	<td>
-		<?php print_email_input( 'email', $t_user['email'] ) ?>
+		<?php
+			// With LDAP
+			if ( $t_ldap && ON == config_get( 'use_ldap_email' ) ) {
+				echo string_display_line( user_get_email( $t_user_id ) );
+			}
+			// Without LDAP
+			else {
+				print_email_input( 'email', $t_user['email'] );
+			}
+		?>
 	</td>
 </tr>
 
 <!-- Access Level -->
 <tr <?php echo helper_alternate_class() ?>>
 	<td class="category">
-		<?php echo lang_get( 'access_level' ) ?>:
+		<?php echo lang_get( 'access_level' ) ?>
 	</td>
 	<td>
 		<select name="access_level">
-			<?php print_enum_string_option_list( 'access_levels', $t_user['access_level'] ) ?>
+			<?php
+				$t_access_level = $t_user['access_level'];
+				if ( !MantisEnum::hasValue( config_get( 'access_levels_enum_string' ), $t_access_level ) ) {
+					$t_access_level = config_get( 'default_new_account_access_level' );
+				}
+				print_project_access_levels_option_list( $t_access_level )
+			?>
 		</select>
 	</td>
 </tr>
@@ -99,7 +145,7 @@
 <!-- Enabled Checkbox -->
 <tr <?php echo helper_alternate_class() ?>>
 	<td class="category">
-		<?php echo lang_get( 'enabled' ) ?>:
+		<?php echo lang_get( 'enabled' ) ?>
 	</td>
 	<td>
 		<input type="checkbox" name="enabled" <?php check_checked( $t_user['enabled'], ON ); ?> />
@@ -109,7 +155,7 @@
 <!-- Protected Checkbox -->
 <tr <?php echo helper_alternate_class() ?>>
 	<td class="category">
-		<?php echo lang_get( 'protected' ) ?>:
+		<?php echo lang_get( 'protected' ) ?>
 	</td>
 	<td>
 		<input type="checkbox" name="protected" <?php check_checked( $t_user['protected'], ON ); ?> />
@@ -119,6 +165,10 @@
 <!-- Submit Button -->
 <tr>
 	<td colspan="2" class="center">
+	<?php if ( config_get( 'enable_email_notification' ) == ON ) {
+		echo lang_get( 'notify_user' ); ?>
+		<input type="checkbox" name="send_email_notification" checked />
+	<?php } ?>
 		<input type="submit" class="button" value="<?php echo lang_get( 'update_user_button' ) ?>" />
 	</td>
 </tr>
@@ -129,49 +179,63 @@
 <br />
 
 <!-- RESET AND DELETE -->
-<div class="border-center">
-<!-- Reset Button -->
+<?php
+	$t_reset = $t_user['id'] != auth_get_current_user_id()
+		&& helper_call_custom_function( 'auth_can_change_password', array() );
+	$t_unlock = OFF != config_get( 'max_failed_login_count' ) && $t_user['failed_login_count'] > 0;
+	$t_delete = !( ( user_is_administrator( $t_user_id ) && ( user_count_level( config_get_global( 'admin_site_threshold' ) ) <= 1 ) ) );
+
+	if( $t_reset || $t_unlock || $t_delete ) {
+?>
+<div class="border center">
+
+<!-- Reset/Unlock Button -->
+<?php if( $t_reset || $t_unlock ) { ?>
 	<form method="post" action="manage_user_reset.php">
 <?php echo form_security_field( 'manage_user_reset' ) ?>
 		<input type="hidden" name="user_id" value="<?php echo $t_user['id'] ?>" />
+<?php if( $t_reset ) { ?>
 		<input type="submit" class="button" value="<?php echo lang_get( 'reset_password_button' ) ?>" />
+<?php } else { ?>
+		<input type="submit" class="button" value="<?php echo lang_get( 'account_unlock_button' ) ?>" />
+<?php } ?>
 	</form>
+<?php } ?>
 
 <!-- Delete Button -->
-<?php if ( !( ( ADMINISTRATOR <= $t_user['access_level'] ) && ( 1 >= user_count_level( ADMINISTRATOR ) ) ) ) { ?>
+<?php if ( $t_delete ) { ?>
 	<form method="post" action="manage_user_delete.php">
 <?php echo form_security_field( 'manage_user_delete' ) ?>
-
 		<input type="hidden" name="user_id" value="<?php echo $t_user['id'] ?>" />
 		<input type="submit" class="button" value="<?php echo lang_get( 'delete_user_button' ) ?>" />
 	</form>
 <?php } ?>
 </div>
-<br />
-<div align="center">
-<?php
-	if ( ( ON == config_get( 'send_reset_password' ) ) && ( ON == config_get( 'enable_email_notification' ) ) ) {
-		echo lang_get( 'reset_password_msg' );
-	} else {
-		echo lang_get( 'reset_password_msg2' );
-	}
-?>
-</div>
+	<?php if( $t_reset ) { ?>
+	<div align="center">
+	<br />
+	<?php
+		if ( ( ON == config_get( 'send_reset_password' ) ) && ( ON == config_get( 'enable_email_notification' ) ) ) {
+			echo lang_get( 'reset_password_msg' );
+		} else {
+			echo lang_get( 'reset_password_msg2' );
+		}
+	?>
+	</div>
+	<?php } ?>
+<?php } ?>
 
 
 <!-- PROJECT ACCESS (if permissions allow) and user is not ADMINISTRATOR -->
 <?php if ( access_has_global_level( config_get( 'manage_user_threshold' ) ) &&
-    !access_has_global_level( ADMINISTRATOR, $t_user['id'] ) ){
+    !user_is_administrator( $t_user_id ) ) {
 ?>
 <br />
 <div align="center">
-<form method="post" action="manage_user_proj_add.php">
-<?php echo form_security_field( 'manage_user_proj_add' ) ?>
 <table class="width75" cellspacing="1">
 <!-- Title -->
 <tr>
 	<td class="form-title" colspan="2">
-		<input type="hidden" name="user_id" value="<?php echo $t_user['id'] ?>" />
 		<?php echo lang_get( 'add_user_title' ) ?>
 	</td>
 </tr>
@@ -179,17 +243,20 @@
 <!-- Assigned Projects -->
 <tr <?php echo helper_alternate_class( 1 ) ?> valign="top">
 	<td class="category" width="30%">
-		<?php echo lang_get( 'assigned_projects' ) ?>:
+		<?php echo lang_get( 'assigned_projects' ) ?>
 	</td>
 	<td width="70%">
 		<?php print_project_user_list( $t_user['id'] ) ?>
 	</td>
 </tr>
 
-<!-- Unassigend Project Selection -->
+<form method="post" action="manage_user_proj_add.php">
+<?php echo form_security_field( 'manage_user_proj_add' ) ?>
+		<input type="hidden" name="user_id" value="<?php echo $t_user['id'] ?>" />
+<!-- Unassigned Project Selection -->
 <tr <?php echo helper_alternate_class() ?> valign="top">
 	<td class="category">
-		<?php echo lang_get( 'unassigned_projects' ) ?>:
+		<?php echo lang_get( 'unassigned_projects' ) ?>
 	</td>
 	<td>
 		<select name="project_id[]" multiple="multiple" size="5">
@@ -201,14 +268,11 @@
 <!-- New Access Level -->
 <tr <?php echo helper_alternate_class() ?> valign="top">
 	<td class="category">
-		<?php echo lang_get( 'access_level' ) ?>:
+		<?php echo lang_get( 'access_level' ) ?>
 	</td>
 	<td>
 		<select name="access_level">
-		<?php
-			# No administrator choice
-			print_project_access_levels_option_list( config_get( 'default_new_account_access_level' ) )
-		?>
+			<?php print_project_access_levels_option_list( config_get( 'default_new_account_access_level' ) ) ?>
 		</select>
 	</td>
 </tr>
@@ -219,19 +283,13 @@
 		<input type="submit" class="button" value="<?php echo lang_get( 'add_user_button' ) ?>" />
 	</td>
 </tr>
-</table>
 </form>
+</table>
 </div>
 <?php
 	} # End of PROJECT ACCESS conditional section
-?>
 
-
-
-<!-- ACCOUNT PREFERENCES -->
-<?php
 	include ( 'account_prefs_inc.php' );
-	edit_account_prefs( $t_user['id'], false, false, 'manage_user_edit_page.php?user_id=' . $c_user_id );
-?>
+	edit_account_prefs( $t_user['id'], false, false, 'manage_user_edit_page.php?user_id=' . $t_user_id );
 
-<?php html_page_bottom1( __FILE__ ) ?>
+	html_page_bottom();
